﻿using System.Windows;
using System.Windows.Media;
using System.Windows.Media.Imaging;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 윈도우 로드시 처리하기 - Window_Loaded(sender, e)

        /// <summary>
        /// 윈도우 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            const string FONT_NAME = "Times New Roman";
            const double EM_SIZE   = 40;

            LinearGradientBrush brush = new LinearGradientBrush();

            brush.GradientStops.Add(new GradientStop(Colors.Red   , 0.0      ));
            brush.GradientStops.Add(new GradientStop(Colors.Orange, 1.0 / 6.0));
            brush.GradientStops.Add(new GradientStop(Colors.Yellow, 2.0 / 6.0));
            brush.GradientStops.Add(new GradientStop(Colors.Lime  , 3.0 / 6.0));
            brush.GradientStops.Add(new GradientStop(Colors.Blue  , 4.0 / 6.0));
            brush.GradientStops.Add(new GradientStop(Colors.Indigo, 5.0 / 6.0));
            brush.GradientStops.Add(new GradientStop(Colors.Violet, 1.0      ));

            Pen rectanglePen = new Pen(brush, 20);

            Brush backgroundBrush = new SolidColorBrush(Color.FromArgb(255, 240, 240, 240));

            RenderTargetBitmap bitmap1 = DrawingContextExtension.GetRenderTargetBitmap
            (
                "Left\nJustified",
                96,
                96,
                FONT_NAME,
                EM_SIZE,
                TextAlignment.Left,
                backgroundBrush,
                rectanglePen,
                brush,
                new Thickness(0)
            );

            image1.Source = bitmap1;

            RenderTargetBitmap bitmap2 = DrawingContextExtension.GetRenderTargetBitmap
            (
                "Center\nJustified",
                96,
                96,
                FONT_NAME,
                EM_SIZE,
                TextAlignment.Center,
                backgroundBrush,
                rectanglePen,
                brush,
                new Thickness(0)
            );

            image2.Source = bitmap2;

            RenderTargetBitmap bitmap3 = DrawingContextExtension.GetRenderTargetBitmap
            (
                "Right\nJustified",
                96,
                96,
                FONT_NAME,
                EM_SIZE,
                TextAlignment.Right,
                backgroundBrush,
                rectanglePen,
                brush,
                new Thickness(0)
            );

            image3.Source = bitmap3;

            RenderTargetBitmap bitmap4 = DrawingContextExtension.GetRenderTargetBitmap
            (
                "Margin\n(20)",
                96,
                96,
                FONT_NAME,
                EM_SIZE,
                TextAlignment.Center,
                backgroundBrush,
                rectanglePen,
                brush,
                new Thickness(20)
            );

            image4.Source = bitmap4;

            RenderTargetBitmap bitmap5 = DrawingContextExtension.GetRenderTargetBitmap
            (
                "Margin\n(20,0,0,20)",
                96,
                96,
                FONT_NAME,
                EM_SIZE,
                TextAlignment.Center,
                backgroundBrush,
                rectanglePen,
                brush,
                new Thickness(20, 0, 0, 20)
            );

            image5.Source = bitmap5;

            RenderTargetBitmap bitmap6 = DrawingContextExtension.GetRenderTargetBitmap
            (
                "Margin\n(0,20,20,0)",
                96,
                96,
                FONT_NAME,
                EM_SIZE,
                TextAlignment.Center,
                backgroundBrush,
                rectanglePen,
                brush,
                new Thickness(0, 20, 20, 0)
            );

            image6.Source = bitmap6;            
        }

        #endregion
    }
}